pub struct ScssRuleSet {
pub span: Range<usize>,
pub selector: ScssSelector,
pub block: ScssBlock,
}Expand description
A rule set consisting of a selector and a block
Fields
span: Range<usize>The source range of the rule set
selector: ScssSelectorThe selector
block: ScssBlockThe block containing declarations and nested rules
Implementations
Sourceimpl ScssRuleSet
impl ScssRuleSet
Sourcepub fn traverse<V: ScssVisitor>(&self, visitor: &mut V)
pub fn traverse<V: ScssVisitor>(&self, visitor: &mut V)
Traverses the rule set with the given visitor.
Sourcepub fn traverse_mut<V: ScssVisitorMut>(&mut self, visitor: &mut V)
pub fn traverse_mut<V: ScssVisitorMut>(&mut self, visitor: &mut V)
Mutably traverses the rule set with the given visitor.